from setuptools import setup

setup(
    name='pointhelper',
    version='0.0.2',
    packages=['pointhelper'],
    author='jim',
    author_email='847734876@qq.com',
    license='MIT',
    url='https://github.com/JimXu1989/pointhelper'
)
